const mongoose = require('mongoose');
const { database } = require('../src/server/config/keys');
const activities = require('./data/Actividades.json');
const activityModel = require('../src/models/activity');
const projectModel = require('../src/models/project');

mongoose.connect(database.URI, { useNewUrlParser: true })
	.then(db => console.log('DB Connected'))
	.catch(err => console.error(err));

const createActivities = async () => {
	const createActivity = async activity => {
		const activityData = new activityModel({
			Actividad_es: activity.Actividad_es,
			N_veces: activity.N_veces,
			Coste: activity.Coste
		});

		const nproj = activity.n_proyecto;

		const session = await activityModel.startSession();
		session.startTransaction();

		try {
			const options = { session };

			const newActivity = await activityData.save(options);

			const project = await projectModel.findOne({ Identificador: nproj });

			if (project.Actividades) {
				project.Actividades.push(newActivity._id);
			}

			else {
				project.Actividades = [newActivity._id]
			}

			await project.save(options);

			// OK: Commit transaction
			await session.commitTransaction();
			session.endSession();
			return true;
		}

		catch (error) {
			// KO: Abort transaction
			await session.abortTransaction();
			session.endSession();
			console.log(error)
		}
	}

	for (const activity of activities)
		await createActivity(activity);
	
	console.log('Finalizado');
};

createActivities();