// LIBRERIAS Y FRAMEWORKS
import React, { useState, useEffect, useReducer } from 'react';
import { BrowserRouter, Route, Switch } from 'react-router-dom';

//COMPONENTES
import { Header } from './components/header/';
import { Home } from './components/home/';
import { Graphs } from './components/graphs/'
import { Footer } from './components/footer/';
import { Edition } from './components/edition/';

// CONTEXTOS, REDUCERS ...
import GlobalContext from './contexts/global/Context';
import { log, initAuth } from './contexts/global/AuthReducer';

import './styles/common.scss';

const App = () => {
    const resolution = useWidth();
    const [stateAuth, setAuth] = useReducer(log, initAuth(localStorage));

    return (
        <BrowserRouter>
            <GlobalContext.Provider value={{ resolution, stateAuth, setAuth }}>
                <header>
                    <Route path="/" component={Header} />
                </header>
                <main>
                    <Switch>
                        <Route path="/" exact component={Home} />
                        <Route path="/account" exact render={() => <h1>Home page</h1>} />
                        <Route path="/data" exact component={Edition} />
                        <Route path="/graphics" exact component={Graphs} />
                        <Route path="/users" exact render={() => <h1>Home page</h1>} />
                    </Switch>
                </main>
                <footer>
                    <Route path="/" component={Footer} />
                </footer>
            </GlobalContext.Provider>
        </BrowserRouter>
    );
};

const getResolution = () => {
    const screen = {
        XS: 450,
        SM: 700,
        MD: 950
    };

    if (window.innerWidth < screen.XS)
        return 'xs';
    else if (window.innerWidth >= screen.XS && window.innerWidth < screen.SM)
        return 'sm';
    else if (window.innerWidth >= screen.SM && window.innerWidth < screen.MD)
        return 'md';
    else if (window.innerWidth >= screen.MD) {
        return 'lg';
    }
};

const useWidth = () => {
    const [resolution, setResolution] = useState(getResolution());

    useEffect(() => {
        const handleResize = () => {
            setResolution(getResolution());
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);
    return resolution;
};

export default App;