// LIBRERIAS Y FRAMEWORKS
import React, { useContext, useState, useEffect } from 'react';
import { Redirect } from 'react-router'

//COMPONENTES
import { Container, Row, Col, Select, Form } from '../../global/';

// HELPERS Y HANDLERS
import Forms from '../../helpers/forms/Forms';
import AlertHandler from '../../global/AlertHandler';

// CONTEXTOS, REDUCERS ...
import GlobalContext from '../../contexts/global/Context';

//ESTILOS
import './styles/Editions.scss';
import Handlers from '../../helpers/Handlers';

const Edition = () => {
	const { resolution, stateAuth } = useContext(GlobalContext);
	if (!stateAuth.isAuth) return <Redirect to="/" />


	const [state, setState] = useState({
		opcion1: null,
		types: null
	})

	const selectOption1 = getOption1(resolution, setState);
	const formOption2 = getOption2(resolution, state, setState)

	const getTypes = async () => {
		const data = await Handlers.getTypes();
		if (data.types)
			setState({ ...state, types: data.types })
		else
			AlertHandler.createAlert({
				data: [
					'No existen tipos registrados en la base de datos'
				],
				title: 'No existen datos',
				type: 'error'
			});
	}

	useEffect(() => {
		if (state.opcion1)
			getTypes();

	}, [state.opcion1])

	return (
		<Container size={'md'}>
			<Row styles={["padd-v-05", "flex-c-c"]}>
				<Col size={resolution} fixed={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
					<h3 styleName='selecText'> Aquí puede editar o insertar nuevos datos de los proyectos, seleccione la opción que desee realizar.</h3>
				</Col>
				{selectOption1}
				{formOption2}
			</Row>
		</Container>
	)
}

const getOption1 = (resolution, setState) => {
	const option1Handler = getOption1Handler(setState);
	const properties = {
		placeHolder: 'Seleccione una opción',
		name: 'principalVar',
		values: [
			'Insertar',
			'Editar'
		],
		size: 'md',
		onChange: option1Handler
	}

	const option1 =
		<Col size={resolution} xs={12} sm={12} md={12} lg={12} styles={['marg-v-05', 'padd-h-025']}>
			<Select {...properties} />
		</Col>

	return option1;
}

const getOption1Handler = (setState) => {

	const option1Handler = event => {
		setState({
			opcion1: event.target.selectedOptions[0].text
		})
	}

	return option1Handler;
}

const getOption2 = (resolution, state) => {
	if (state.opcion1 && state.types) {
		if (state.opcion1 === 'Insertar') {
			const onSubmit = getInsertHandler();
			const handlerSelType = getHandlerSelType();
			const handlerInpType = getHandlerInpType();

			const schema = Forms.InsertProject(state.types, handlerSelType, handlerInpType);

			return (
				<>
					<Col size={resolution} fixed={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
						<h3 styleName='selecText'> Inserte los datos de su nuevo proyecto</h3>
					</Col>
					<Col size={resolution} xs={12} sm={12} md={12} lg={12} styles={['marg-v-05', 'padd-h-05']}>
						<Form {...{ resolution, schema, onSubmit }} />
					</Col>
				</>
			)
		}
	}


	return null;
}

const getInsertHandler = () => {

	const onSubmit = async event => {
		event.preventDefault()
		const elements = event.target.elements;
		var values = {}

		for (var i of elements) {
			if (!i.value || i.value === 0) {
				if (i.name && i.name !== 'type' && i.name !== 'typeSel') {
					AlertHandler.createAlert({
						data: ['Uno o varios campos son incorrectos o están incompletos'],
						title: 'No existen datos',
						type: 'error'
					});
					return false;
				}
			}
			else {
				console.log(i)
				if (i.name) {
					if (i.name === 'typeSel' || i.name === 'effectiveness' || i.name === 'efficiency' || i.name === 'impact' || i.name === 'relevance' || i.name === 'participation' || i.name === 'viability' || i.name === 'visibility') {
						if (i.selectedIndex !== 0 && i.options[i.selectedIndex].text)
							values = { ...values, [i.name]: i.options[i.selectedIndex].text }
					}
					else
						values = { ...values, [i.name]: i.value }
				}
			}
		}

		const flag = await Handlers.insertProject(values);
		console.log(flag);
		return true;

	}

	return onSubmit;
}

const getHandlerSelType = () => {
	const handlerSelType = event => {
		if (event.target.value != 0)
			document.getElementsByName('type')[0].disabled = true
		else
			document.getElementsByName('type')[0].disabled = false
	}
	return handlerSelType
}

const getHandlerInpType = () => {
	const handlerInpType = event => {
		if (event.target.value.length > 0)
			document.getElementsByName('typeSel')[0].disabled = true
		else
			document.getElementsByName('typeSel')[0].disabled = false
	}
	return handlerInpType

}

export default Edition;