// LIBRERIAS Y FRAMEWORKS
import React, { useContext, useState, useEffect } from 'react';
import { LineChart, Line, CartesianGrid, XAxis, YAxis, ResponsiveContainer, Tooltip, Label, Legend } from 'recharts';

//COMPONENTES
import { Container, Row, Col, Select, Parallax } from '../../global/';

// HELPERS Y HANDLERS
import Handlers from '../../helpers/Handlers';

// CONTEXTOS, REDUCERS ...
import GlobalContext from '../../contexts/global/Context';

//ESTILOS
import styles from './styles/Graphs.scss'

const Graphs = () => {
	const { resolution } = useContext(GlobalContext);
	const [state, setState] = useState({
		ejeX: null,
		ejeY: null,
		renderLineChart: null,
		...setParallaxDim(resolution)
	})

	const selectXAxis = getXAxisSelect(resolution, setState);
	const selectYAxis = getYAxisSelect(resolution, state, setState);

	const getDataGraphic = async (ejeX, ejeY) => {
		const response = await Handlers.getDataGraphic(ejeX, ejeY);
		if (response.data) {

			const name = ejeY === 'Eficiencia' ? ejeY + '  [1 -> MUY BAJA || 5 -> MUY ALTA]' : ejeY
			const dominio = getMaxandMin(response.data, 'varCruzada')
			const label = ejeX === 'Eficiencia' ? ejeX + '  [1 -> MUY BAJA || 5 -> MUY ALTA]' : ejeX

			const renderLineChart =
				<Col size={resolution} fixed={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]} class={[styles.graphContainer]}>
					<ResponsiveContainer width="100%" height={400}>
						<LineChart data={response.data} margin={{ top: 5, right: 10, bottom: 15, left: 0 }}>
							<Line name={name} type="monotone" dataKey="varCruzada" stroke="#8884d8" activeDot={{ r: 8 }} />
							<CartesianGrid stroke="#ccc" strokeDasharray="5 5" />
							<Tooltip label={{ value: ejeY }} />
							<XAxis dataKey='anio'>
								<Label value={ejeX} offset={-15} position="insideBottom" />
							</XAxis>
							<YAxis dataKey='varCruzada' domain={dominio} />
							<Legend verticalAlign="top" height={36} />
						</LineChart>
					</ResponsiveContainer>
				</Col >
			setState({ ...state, renderLineChart })
		}

	}

	useEffect(() => {
		if (state.ejeY) {
			getDataGraphic(state.ejeX, state.ejeY);

		}
	}, [state.ejeY]);

	return (
		<>
			<Container size={'md'} styles={["margin-bot5"]}>
				<Row styles={["padd-v-05", "flex-c-c"]}>
					<Col size={resolution} fixed={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
						<h3 styleName='selecText'> Seleccione una de las dos opciones, si eliges 'Año' aparecerá en el eje horizontal, si elijes 'Eficiencia' aparecerá en el eje vertical</h3>
					</Col>
					{selectXAxis}
				</Row>
				<Row styles={["padd-v-05", "flex-c-c"]}>
					<Col size={resolution} fixed={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
						<h3 styleName='selecText'> Seleccione la variable que deseas cruzar</h3>
					</Col>
					{selectYAxis}
					{state.renderLineChart}
				</Row>

			</Container>
			<Parallax id='banner' img={'/img/escuela.jpg'} y={state.yOffset} x={state.xOffset} clip={'no-clip'} height={state.height} h={state.hOffset} ratio={state.ratio} />
		</>
	)

}

const getXAxisSelect = (resolution, setState) => {
	const xHandler = getXHandler(setState);
	const properties = {
		placeHolder: 'Seleccione el tipo',
		name: 'principalVar',
		values: [
			'Año',
			'Eficiencia'
		],
		size: 'md',
		onChange: xHandler
	}

	const xSelect =
		<Col size={resolution} xs={12} sm={12} md={6} lg={6} styles={['marg-v-05', 'padd-h-025']}>
			<Select {...properties} />
		</Col>

	return xSelect;
}

const getYAxisSelect = (resolution, state, setState) => {
	const yHandler = getYHandler(state, setState);
	var properties;
	if (state.ejeX === 'Año') {
		properties = {
			placeHolder: 'Seleccione una opción',
			name: 'secondaryVar',
			values: [
				'Eficiencia',
				'Actividades',
				'Beneficiarios',
				'Entidades',
				'Cofinanciadores',
				'Lugares',
				'Paises',
				'Sectores'
			],
			size: 'md',
			onChange: yHandler
		}
	}
	else if (state.ejeX === 'Eficiencia') {
		properties = {
			placeHolder: 'Seleccione una opción',
			name: 'secondaryVar',
			values: [
				'Años',
				'Actividades',
				'Beneficiarios',
				'Entidades',
				'Cofinanciadores',
				'Lugares',
				'Paises',
				'Sectores'
			],
			size: 'md',
			onChange: yHandler
		}
	}
	const ySelect = properties ?
		<Col size={resolution} xs={12} sm={12} md={6} lg={6} styles={['marg-v-05', 'padd-h-025']}>
			<Select {...properties} />
		</Col> : null


	return ySelect;
}

const getXHandler = (setState) => {

	const xHandler = event => {
		setState({
			ejeX: event.target.selectedOptions[0].text,
			ejeY: null
		})
	}

	return xHandler;
}

const getYHandler = (state, setState) => {

	const yHandler = event => {
		setState({
			...state,
			ejeY: event.target.selectedOptions[0].text
		})
	}

	return yHandler;
}

const getMaxandMin = (arr, prop) => {
	var max;
	for (var i = 0; i < arr.length; i++) {
		if (!max || parseInt(arr[i][prop]) > parseInt(max))
			max = arr[i][prop];
	}
	return [0, parseFloat(max)];
}

const setParallaxDim = resolution => {
	let dim = {
		yOffset: 0,
		xOffset: 0,
		height: 0,
		hOffset: 0,
		ratio: 0
	}

	switch (resolution) {
		case 'lg':
			dim.yOffset = 300;
			dim.xOffset = 0;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'md':
			dim.yOffset = 120;
			dim.xOffset = 250;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'sm':
			dim.yOffset = 200;
			dim.xOffset = 300;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'xs':
			dim.yOffset = 200;
			dim.xOffset = 380;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
	}

	return { ...dim };
}
export default Graphs;