// LIBRERIAS Y FRAMEWORKS
import React, { useContext } from 'react';
import { Link } from 'react-router-dom';

//COMPONENTES
import { Container, Row, Col, Svg, Wrapper } from '../../global/';

// CONTEXTOS, REDUCERS, HELPERS ...
import Handlers from '../../helpers/Handlers';
import GlobalContext from '../../contexts/global/Context';

//ESTILOS
import styles from './styles/Header.scss'

const Header = () => {
	const { resolution, stateAuth, setAuth } = useContext(GlobalContext);
	const menu = renderMenu();
	console.log(stateAuth);

	const account = stateAuth.isAuth ?
		<>
			<div styleName='accountIcon'
				onMouseOver={() => handleAccountOver()}
				onMouseOut={() => handleAccountOut()}>
				<a>
					<Svg xlink={'/svg/sprites.svg#account'} />
				</a>
			</div>
			<div id='menu-account' styleName='accountMenu hide_v'
				onMouseOver={() => handleAccountOver()}
				onMouseOut={() => handleAccountOut()}>
				<a onClick={event => Handlers.getSignOutHandler(event, stateAuth, setAuth)}>
					<p>Cerrar sesion</p>
				</a>
			</div>
		</>
		: null

	const options = stateAuth.isAuth ?
		<>
			<Link to="/data">
				<h3>Datos</h3>
			</Link>
			<Link to="/graphics">
				<h3>Gráficas</h3>
			</Link>
			<Link to="/users">
				<h3>Usuarios</h3>
			</Link>
		</> :
		<Link to="/graphics">
			<h3>Gráficas</h3>
		</Link>

	return (
		<>
			<Container>
				<Row styles={["padd-v-05"]}>
					<Col size={resolution} xs={6} sm={2} md={1} lg={1} styles={["padd-h-1", "flex-s-c"]}>
						<Link to="/">
							<img styleName='logo' src="./img/logo-uva.png" alt="LogoUVa" />
						</Link>
					</Col>
					<Wrapper size={resolution} sm={true} md={true} lg={true}>
						<Col size={resolution} sm={7} md={8} lg={8} styles={["padd-h-1", "flex-s-c"]}>
							{options}
						</Col>
					</Wrapper>
					<Col size={resolution} xs={6} sm={3} md={3} lg={3} styles={["flex-e-c"]}>
						{account}
						<Wrapper size={resolution} xs={true}>
							<a onClick={() => handleMenu()}>
								<Svg xlink={'/svg/sprites.svg#menu'} />
							</a>
						</Wrapper>
					</Col>
				</Row>
			</Container>
			<div id='menu-mobile' styleName='menu-mobile hide'>
				<div styleName='title-menu'>
					<h2>MENU</h2>
					<div styleName='close'>
						<a onClick={() => handleMenu()}>
							<Svg xlink={'/svg/sprites.svg#cross'} />
						</a>
					</div>
				</div>
				{menu}
			</div>
		</>
	)
}

const handleMenu = () => {
	const menu = document.getElementById('menu-mobile');

	if (menu.classList.contains(styles.hide))
		menu.classList.replace(styles.hide, styles.show);

	else
		menu.classList.replace(styles.show, styles.hide);


};

const handleAccountOver = () => {
	const menuAcc = document.getElementById('menu-account');

	menuAcc.classList.replace(styles.hide_v, styles.show_v);



};

const handleAccountOut = () => {
	const menuAcc = document.getElementById('menu-account');

	menuAcc.classList.replace(styles.show_v, styles.hide_v);


};

const renderMenu = () => {
	const sections =
		<>
			<Link to='/'>
				<div>
					<h4>Datos</h4>
				</div>
			</Link>
			<Link to='/'>
				<div>
					<h4>Gráficas</h4>
				</div>
			</Link>
			<Link to='/'>
				<div>
					<h4>Usuarios</h4>
				</div>
			</Link>
		</>

	return (
		<>
			<div>
				{sections}
			</div>
		</>
	);

};

export default Header;