// LIBRERIAS Y FRAMEWORKS
import React, { useContext, useState, useEffect } from 'react';

//COMPONENTES
import { Container, Row, Col, Form, Parallax } from '../../global/';

// HELPERS Y HANDLERS
import Forms from '../../helpers/forms/Forms';
import Handlers from '../../helpers/Handlers';

// CONTEXTOS, REDUCERS ...
import GlobalContext from '../../contexts/global/Context';

//ESTILOS
import './styles/Home.scss'

const Home = () => {
	const { stateAuth, setAuth, resolution } = useContext(GlobalContext);

	const init = getInit(stateAuth, setAuth, resolution);

	const [state, setState] = useState({ ...setParallaxDim(resolution) });

	useEffect(() => {
		setState({ ...setParallaxDim(resolution) });
	}, [resolution]);

	return (
		<>
			<Container size={'md'}>
				<Row styles={["padd-v-05"]}>
					{init}
				</Row>
			</Container>
			<Parallax id='banner' img={'/img/paisaje.jpg'} y={state.yOffset} x={state.xOffset} clip={'no-clip'} height={state.height} h={state.hOffset} ratio={state.ratio} />
		</>
	)
}

const setParallaxDim = resolution => {
	let dim = {
		yOffset: 0,
		xOffset: 0,
		height: 0,
		hOffset: 0,
		ratio: 0
	}

	switch (resolution) {
		case 'lg':
			dim.yOffset = 300;
			dim.xOffset = 0;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'md':
			dim.yOffset = 120;
			dim.xOffset = 250;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'sm':
			dim.yOffset = 200;
			dim.xOffset = 300;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
		case 'xs':
			dim.yOffset = 200;
			dim.xOffset = 380;
			dim.height = 30;
			dim.hOffset = 20;
			dim.ratio = 0.25;
			break;
	}

	return { ...dim };
}

const getInit = (stateAuth, setAuth, resolution) => {
	const schema = Forms.Login();
	const onSubmit = event => Handlers.getSignInHandler(event, stateAuth, setAuth);

	const init = stateAuth.isAuth ?
		<Col size={resolution} xs={12} sm={12} md={12} lg={12} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
			<div styleName='intro-ctn'>
				<p>
					Bienvenido,
				</p>
				<p>
					en esta plataforma encontrarás datos relacionados
					con la eficiencia en la cooperación internacional para el desarrollo.
				</p>
				<p>
					En el menú superior podrás acceder a las distintas secciones de las que dispone esta plataforma web.
				</p>
			</div>
		</Col> :
		<>
			<Col size={resolution} xs={12} sm={6} md={6} lg={6} styles={["padd-h-1", "padd-v-1", "flex-sb-c", "dir-col"]}>
				<div styleName='intro-ctn'>
					<p>
						Bienvenido,
						</p>
					<p>
						en esta plataforma encontrarás datos relacionados
						con la eficiencia en la cooperación internacional para el desarrollo.
						</p>
					<p>
						Si tienes cuenta de usuario, puedes iniciar sesión
						desde el formulario que se muestra a continuación.
						</p>
				</div>
			</Col>
			<Col size={resolution} xs={12} sm={6} md={5} lg={6} styles={["padd-h-1", "padd-v-1", "flex-s-c"]}>
				<Form {...{ resolution, schema, onSubmit }} />
			</Col>
		</>
	return init;
}

export default Home;