import React from 'react';
import ReactDOMServer from 'react-dom/server';

import styles from "./styles/Alert.scss";

export default class AlertHandler {

	/**
	 * @param  {Object} message - Debe recibir al menos un array de mensajes y la colección de estilos indicada
	 * 	@param {String} message.title Título que precede al array de mensajes
	 * 	@param  {[String]} [message.data] - Array de mensajes a mostrar
	 * 	@param  {String} message.type - Tipo de mensajes, puede tener los valores (error,warn,success o info)
	 */

	static createAlert(message) {
		if (!message.data) {
			return false;
		}

		const getProperties = message => {

			let messages = message.data.map((i, index) => {
				return (
					<span key={index}>
						{i}
					</span>
				)
			}
			);

			return messages;
		};

		const removeElement = element => element.remove();

		const animationEnd = (element, now) => {

			setTimeout(() => {
				element.classList.replace(styles.fadeInDown, styles.fadeOutUp);
			}, 3500);

			if (now) {
				element.classList.replace(styles.fadeInDown, styles.fadeOutUp);
				setTimeout(() => {
					element.addEventListener(
						'animationend',
						removeElement(element));
				}, 2000);
			}
			else
				setTimeout(() => {
					element.classList.replace(styles.fadeInDown, styles.fadeOutUp);
					element.addEventListener(
						'animationend',
						removeElement(element));
				}, 4500);

		};

		const messages = getProperties(message);
		const style = ["fadeInDown", "animated", "alert-container", `alert-${message.type}`];
		const main = document.getElementsByTagName('main')[0];

		const html = ReactDOMServer.renderToStaticMarkup(
			<div
				id="alert"
				styleName={style.join(" ")}
			>
				<div styleName={`icon ${message.type}`} />
				<div styleName="wrapper">
					<span>{message.title}</span>
					{messages}
				</div>
				<a>
					<svg styleName="close" viewBox="0 0 16 16">
						<use xlinkHref="/svg/sprites.svg#cross" />
					</svg>
				</a >
			</div >);

		main.insertAdjacentHTML('afterbegin', html);

		main.children[0].onanimationend = animationEnd(main.children[0], false);
		main.children[0].children[2].onclick = () => animationEnd(main.children[0], true);
	}
}
