import React from 'react';
import { Row, Col } from '../';
import { Input, LinkTo, Submit, Robinson, Select, CheckBox } from '../';

/**
 * @param {Object} props
 * @param {String} props.resolution String con la resolución de pantalla actual
 * @param {function} props.onSubmit Manejador del submit del formulario
 * @param {Object} props.schema Objeto con el esquema de los componentes del formulario
 * 	@param {String} props.schema.element Tipo de elemento (input, select)
 * 	@param {Object} props.schema.values Valores propios del elemento
 * 	@param {Number} props.schema.size Valor del Col en resolución MD y LG (1-12)
 */

const Form = props => {
	const form = getForm(props.schema, props.resolution);

	return (
		<form onSubmit={props.onSubmit}>
			<Row>
				{form}
			</Row>
		</form>
	);
};

const getForm = (schema, resolution) => {
	const form = schema.map((i, index) => {
		if (i.element === 'input') {
			const input = {
				key: index,
				resolution,
				size: i.size,
				values: i.values,
				styles: i.styles,
				enableEnter: i.enableEnter
			}
			return getInput(input);
		}
		else if (i.element === 'select') {
			const input = {
				key: index,
				resolution,
				size: i.size,
				values: i.values,
				styles: i.styles,
			}
			return getSelect(input);
		}
		else if (i.element === 'robinson') {
			const input = {
				key: index,
				resolution,
				size: i.size,
				values: i.values
			}
			return getRobinson(input);
		}

		else if (i.element === 'checkbox') {
			const input = {
				key: index,
				resolution,
				size: i.size,
				values: i.values
			}
			return getCheckBox(input);
		}

		else if (i.element === 'link') {
			const input = {
				key: index,
				resolution,
				size: i.size,
				values: i.values,
				styles: i.styles
			}
			return getLink(input);
		}

		else if (i.element === 'submit') {
			return <Submit {...i.values} key={index} disableEnter={event => disableEnter(event)} />
		}
	});

	return form;
};

const getInput = input => {
	const styles = input.styles ? input.styles : ['marg-v-05', 'padd-h-025'];
	const disable = input.enableEnter ? null : event => disableEnter(event);

	if (input.size === 6) {
		return (
			<Col key={input.key} size={input.resolution} xs={12} sm={12} md={6} lg={6} styles={styles}>
				<Input {...input.values} size={input.values.size} disableEnter={disable} />
			</Col>
		);
	}
	else if (input.size === 12) {
		return (
			<Col key={input.key} fixed={12} styles={styles}>
				<Input {...input.values} size={input.values.size} disableEnter={disable} />
			</Col>
		);
	}
};

const getSelect = input => {
	const styles = input.styles ? input.styles : ['marg-v-05', 'padd-h-025'];

	if (input.size === 6) {
		return (
			<Col key={input.key} size={input.resolution} xs={12} sm={12} md={6} lg={6} styles={styles}>
				<Select {...input.values} size={input.values.size} />
			</Col>
		);
	}
	else if (input.size === 12) {
		return (
			<Col key={input.key} fixed={12} styles={styles}>
				<Select {...input.values} size={input.values.size} />
			</Col>
		);
	}
};


const getRobinson = input => {
	const styles = input.styles ? input.styles : ['marg-v-05', 'padd-h-025'];

	if (input.size === 6) {
		return (
			<Col key={input.key} size={input.resolution} xs={12} sm={12} md={6} lg={6} styles={styles}>
				<Robinson {...input.values} disableEnter={event => disableEnter(event)} />
			</Col>
		);
	}
	else if (input.size === 12) {
		return (
			<Col key={input.key} fixed={12} styles={styles}>
				<Robinson {...input.values} disableEnter={event => disableEnter(event)} />
			</Col>
		);
	}
};

const getCheckBox = input => {
	const styles = input.styles ? input.styles : ['marg-v-05', 'padd-h-025'];

	if (input.size === 6) {
		return (
			<Col key={input.key} size={input.resolution} fixed={6} styles={styles}>
				<CheckBox {...input.values} disableEnter={event => disableEnter(event)} />
			</Col>
		);
	}
	else if (input.size === 12) {
		return (
			<Col key={input.key} fixed={12} styles={styles}>
				<CheckBox {...input.values} disableEnter={event => disableEnter(event)} />
			</Col>
		);
	}
};

const getLink = input => {
	const styles = input.styles ? input.styles : ['marg-v-05', 'padd-h-025'];

	if (input.size === 6) {
		return (
			<Col key={input.key} size={input.resolution} xs={12} sm={12} md={6} lg={6} styles={styles}>
				<LinkTo {...input.values} />
			</Col>
		);
	}
	else if (input.size === 12) {
		return (
			<Col key={input.key} fixed={12} styles={styles}>
				<LinkTo {...input.values} />
			</Col>
		);
	}
};

const disableEnter = event => {
	var key;
	if (window.event)
		key = window.event.keyCode;
	else key = event.which;

	if (key === 13) {
		event.preventDefault();
		return false;
	}
	else
		return true;

}

export default Form;