import React from 'react';

import styles from '../styles/Input.scss'

/**
	 * 	@param  {Object} props Objeto compuesto por los siguientes parámetros
	 * 		@param {String} [props.style] Estilos por defecto del proyecto que tendrá cada uno de los input
	 * 		@param {String} [props.placeHolder] Placeholder que parece dentro del input
	 * 		@param {String} props.name Nombre del input
	 * 		@param {String} props.values Valores que tiene para elegir
	 * 		@param {String} props.onChange Funcion que se ejecutará cuando se cambie el valor
	 * 		@param {String} [props.size = md] Altura del input, tres tamaños (sm -> 2.5; md -> 3rem; lg-> 3.5rem)
	 * 
*/

const Select = props => {
	const [ctnStyle, inputStyle] = getStyles(props.size);

	const onChange = props.onChange ? props.onChange : null
	const style = props.style ? props.style : "";
	const placeHolder = props.placeHolder ?
		<option value="0" disabled hidden>{props.placeHolder}</option> :
		null;

	const values = props.values.map((i, index) => {
		return <option key={index + 1} value={index + 1}>{i}</option>
	})

	return (
		<div styleName='input-ctn'>
			<div
				styleName={`${ctnStyle} wrapper`}
				className={style}>
				<select
					styleName={inputStyle}
					name={props.name}
					onChange={onChange}
					defaultValue={0}
				>
					{placeHolder}
					{values}

				</select>
			</div>
		</div>
	)
};

const getStyles = size => {
	let ctnStyle, inputStyle;
	switch (size) {
		case 'sm':
			ctnStyle = 'ctnSm';
			inputStyle = 'selectMd';
			break;
		case 'md':
			ctnStyle = 'ctnMd';
			inputStyle = 'selectMd';
			break;
		case 'lg':
			ctnStyle = 'ctnLg';
			inputStyle = 'selectLg';
			break;
		default:
			ctnStyle = 'ctnMd';
			inputStyle = 'selectMd';
	}

	return [ctnStyle, inputStyle];

};


export default Select;