import React, { useEffect } from 'react';

import '../styles/Parallax.scss';

/**
 * @param {Object} props Propiedades del componente
 * @param {String} props.id ID del div padre sobre el que se realiza el efecto
 * @param {String} props.img Url de la imagen de fondo
 * @param {String} [props.height='25rem'] Altura de la imagen (Formato CSS)
 * @param {Number} [props.y=0] Píxeles de offset de la imagen de fondo
 * @param {String} [props.clip] Nombre de la clase CSS predefinida, que contiene el "clip-path"
 * @param {Number} [props.ratio=0.25] Ratio de scroll entre la pantalla y la imagen (ej: 0.5 => mitad, 1 => mismo y 2 => doble)
 * @param {Object} props.children Contenido interno del div con la imagen de fondo
 */

const Parallax = props => {
	bindScrollEvent(props);

	const { css, styles, height } = getProps(props);

	return (
		<div style={height} styleName={css}>
			<div id={props.id} style={styles} styleName='parallax-before'></div>
			{props.children}
		</div>
	);
};

const getProps = props => {
	const height = {
		height: props.height + 'rem' || '25rem'
	};

	const styles = {
		height: props.height + props.h + 'rem',
		backgroundImage: "url(" + props.img + ")",
		backgroundPositionY: props.y ? `${-props.y}px` : 0,
		backgroundPositionX: props.x ? `${-props.x}px` : 0
	};

	const css = props.clip ? `parallax ${props.clip}` : 'parallax';

	return { css, styles, height };
};

const bindScrollEvent = props => {
	const scrollRatio = props.ratio || 0.5;
	const initialY = -props.y || 0;

	useEffect(() => {

		const handleScroll = () => {
			const scrolled = window.pageYOffset;
			const element = document.getElementById(props.id);

			var translate = `translate3d(0px, ${initialY + scrolled * scrollRatio}px, 0px)`;

			element.style.backgroundPositionY = 0;
			element.style.transform = translate;
		};

		window.addEventListener('scroll', handleScroll);

		return () => {
			window.removeEventListener('scroll', handleScroll);
		};
	}, []);
};

export default Parallax;