import UserAPI from '../graphql/UserAPI';

import AlertHandler from '../global/AlertHandler';
import GraphAPI from '../graphql/GraphAPI';

export default class Handlers {

	static async getSignInHandler(event, stateAuth, setAuth) {
		event.preventDefault();

		if (stateAuth.isAuth) return false;

		const user = {
			name: event.target.name.value,
			password: event.target.pass.value
		};

		const data = await UserAPI.loginUser(user);

		if (data)
			if (!data.errors) {
				localStorage.setItem('token', data.token);
				const timer = 60 * 60 * 1000;
				const expiryDate = new Date(new Date().getTime() + timer);
				localStorage.setItem('expiryDate', expiryDate.getTime());

				setAuth({ type: 'LogIn' });

				AlertHandler.createAlert({
					data: [
						'Bienvenido ', user.name
					],
					title: 'Autenticación exitosa',
					type: 'success'
				});
			} else
				AlertHandler.createAlert({
					data: data.errors,
					title: 'Error en la autenticación',
					type: 'error'
				});
		else
			AlertHandler.createAlert({
				data: [
					'Se ha producido un error en el servidor, por favor, inténtelo de nuevo más tarde'
				],
				title: 'Error en el servidor',
				type: 'error'
			});
	}

	static async getSignOutHandler(event, stateAuth, setAuth) {
		event.preventDefault();

		if (!stateAuth.isAuth) return false;

		setAuth({ type: 'LogOut' });

		AlertHandler.createAlert({
			data: [
				'Se ha cerrado la sesión'
			],
			title: 'Cierre de sesión',
			type: 'info'
		});

	}

	static async getDataGraphic(xAxis, yAxis) {
		const data = await GraphAPI.getGraph(xAxis, yAxis);
		return data
	}

	static async getTypes() {
		const data = await GraphAPI.getTypes();
		return data;
	}

	static async insertProject(values) {
		const flag = await GraphAPI.insertProject(values);
		return flag;
	}
}