const express = require('express');
const routes = require('./routes');
const graphqlHttp = require("express-graphql");
const graphqlSchema = require("../graphql/schema/index");
const graphqlResolver = require("../graphql/resolvers/index");
const auth = require("../middleware/auth");

module.exports = app => {
    //Settings
    app.set('port', process.env.PORT || 3000);

    //Middlewares

    app.use(auth);

    app.use(
        "/graphql",
        graphqlHttp(req => ({
            schema: graphqlSchema,
            rootValue: graphqlResolver,
            graphiql: true
        }))
    );

    //Para poder usar POST por URL
    app.use(express.urlencoded({ extended: false }));
    //Para poder usar JSON
    app.use(express.json());

    //Routes
    routes(app);


    return app;
}