const bcrypt = require("bcryptjs");
const jwt = require("jsonwebtoken");

const { tokenKey } = require("../../config/keys");

const User = require("../../../models/user");

const login = async ({ input }) => {
	const errors = {
		noUser: "El usuario introducido no se encuentra registrado",
		errorPass: "La contraseña introducida es incorrecta"
	};
	const validationErrors = [];
	//Validaciones
	const user = await User.findOne({ name: input.name });
	if (!user) {
		validationErrors.push(errors.noUser);
		return { errors: validationErrors };
	}
	const checkPass = await bcrypt.compare(input.password, user.password);

	if (!checkPass) {
		validationErrors.push(errors.errorPass);
		return { errors: validationErrors };
	}
	//Generando la respuesta
	const token = jwt.sign(
		{
			userId: user._id.toString(),
			name: user.name
		},
		tokenKey,
		{ expiresIn: "1h" }
	);

	return { token };
};


module.exports = {
	login
}