const autoprefixer = require("autoprefixer");
const path = require("path")

const babelLoader = {
  loader: "babel-loader",
  options: {
    cacheDirectory: true
  }
};

const CSSLoader = {
  loader: "css-loader",
  options: {
    modules: true,
    localIdentName: "[name]__[local]"
  }
};

const postCSSLoader = {
  loader: "postcss-loader",
  options: {
    ident: "postcss",
    plugins: () => [
      autoprefixer({
        browsers: [">1%", "last 4 versions", "Firefox ESR", "not ie < 9"]
      })
    ]
  }
};

module.exports = {
  entry: {
    index: "./src/app/index.js"
  },
  output: {
    path: __dirname + '/public/',
    filename: 'bundle.js'
  },
  module: {
    rules: [
      {
        oneOf: [
          {
            test: /\.(js|jsx|mjs)$/,
            exclude: /node_modules/,
            use: [babelLoader]
          },
          {
            test: /\.scss$/,
            exclude: /\.module\.scss$/,
            use: ["style-loader", CSSLoader, postCSSLoader, "sass-loader"]
          },

          {
            test: /\.css$/,
            use: [
              "style-loader",
              {
                loader: "css-loader",
                options: {
                  importLoaders: 1
                }
              },
              {
                loader: "postcss-loader",
                options: {
                  ident: "postcss",
                  plugins: () => [
                    require("postcss-flexbugs-fixes"),
                    autoprefixer({
                      browsers: [
                        ">1%",
                        "last 4 versions",
                        "Firefox ESR",
                        "not ie < 9" // React doesn't support IE8 anyway
                      ],
                      flexbox: "no-2009"
                    })
                  ]
                }
              }
            ]
          }
        ]
      }
    ]
  },
  resolve: {
    alias: {
      react: path.resolve('./node_modules/react'),
      'react-router-dom': path.resolve('./node_modules/react-router-dom')
    }
  }
};
